import React, { useState, useEffect } from 'react';
import RenderCustomComponent from '../../../utilities/RenderCustomComponent';
import ReactSelect from '../../ReactSelect';
import Button from '../../Button';
import Date from './Date';
import Number from './Number';
import Text from './Text';
import useDebounce from '../../../../hooks/useDebounce';
import './index.scss';
const valueFields = {
    Date,
    Number,
    Text,
};
const baseClass = 'condition';
const Condition = (props) => {
    const { fields, dispatch, value, orIndex, andIndex, } = props;
    const [activeField, setActiveField] = useState({ operators: [] });
    const [internalValue, setInternalValue] = useState(value.value);
    const debouncedValue = useDebounce(internalValue, 300);
    useEffect(() => {
        const newActiveField = fields.find((field) => value.field === field.value);
        if (newActiveField) {
            setActiveField(newActiveField);
        }
    }, [value, fields]);
    useEffect(() => {
        dispatch({
            type: 'update',
            orIndex,
            andIndex,
            value: debouncedValue || '',
        });
    }, [debouncedValue, dispatch, orIndex, andIndex]);
    const ValueComponent = valueFields[activeField.component] || valueFields.Text;
    return (React.createElement("div", { className: baseClass },
        React.createElement("div", { className: `${baseClass}__wrap` },
            React.createElement("div", { className: `${baseClass}__inputs` },
                React.createElement("div", { className: `${baseClass}__field` },
                    React.createElement(ReactSelect, { value: fields.find((field) => value.field === field.value), options: fields, onChange: (field) => dispatch({
                            type: 'update',
                            orIndex,
                            andIndex,
                            field,
                        }) })),
                React.createElement("div", { className: `${baseClass}__operator` },
                    React.createElement(ReactSelect, { value: activeField.operators.find((operator) => value.operator === operator.value), options: activeField.operators, onChange: (operator) => dispatch({
                            type: 'update',
                            orIndex,
                            andIndex,
                            operator,
                        }) })),
                React.createElement("div", { className: `${baseClass}__value` },
                    React.createElement(RenderCustomComponent, { CustomComponent: activeField?.props?.admin?.components?.Filter, DefaultComponent: ValueComponent, componentProps: {
                            ...activeField.props,
                            value: internalValue,
                            onChange: setInternalValue,
                        } }))),
            React.createElement("div", { className: `${baseClass}__actions` },
                React.createElement(Button, { icon: "x", round: true, buttonStyle: "icon-label", iconStyle: "with-border", onClick: () => dispatch({
                        type: 'remove',
                        orIndex,
                        andIndex,
                    }) }),
                React.createElement(Button, { icon: "plus", round: true, buttonStyle: "icon-label", iconStyle: "with-border", onClick: () => dispatch({
                        type: 'add',
                        relation: 'and',
                        orIndex,
                        andIndex: andIndex + 1,
                    }) })))));
};
export default Condition;
